as_gridtable.data.frame: Convert a Data Frame to gridtable

View source: R/gridtable.R

as_gridtable.data.frameR Documentation

Convert a Data Frame to gridtable

Description

Build a simple Pandoc grid table from a data frame. Column names become the grid-table header row, each data-frame row becomes one body row, and column widths are calibrated from the widest formatted value in each column.

Usage

## S3 method for class 'data.frame'
as_gridtable(x, ...)

Arguments

x

A data frame.

...

Currently unused.

Value

Character scalar with class gridtable containing a canonical Pandoc grid table.

See Also

as_gridtable, as_gridtable.character

Other gridtable: as.data.frame.gridtable(), as_calibrated(), as_calibrated.data.frame(), as_gridtable(), as_gridtable.character(), kbl(), kbl.calibrated(), kbl.default(), kbl.gridtable(), print.gridtable()


tablet documentation built on July 19, 2026, 9:06 a.m.