| as_calibrated.data.frame | R Documentation |
Assign column-level width attributes to a data frame and return
a calibrated data frame for downstream table rendering. Widths are
recycled as necessary; a warning is issued when the number of supplied
widths differs from the number of columns.
## S3 method for class 'data.frame'
as_calibrated(x, width, ...)
x |
A data frame. |
width |
Character or numeric vector of column widths. Values are recycled as necessary. |
... |
Currently unused. |
A data frame with class calibrated and column-level
width attributes.
as_calibrated, column_spec
Other gridtable:
as.data.frame.gridtable(),
as_calibrated(),
as_gridtable(),
as_gridtable.character(),
as_gridtable.data.frame(),
kbl(),
kbl.calibrated(),
kbl.default(),
kbl.gridtable(),
print.gridtable()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.