| as_gridtable.data.frame | R Documentation |
Build a simple Pandoc grid table from a data frame. Column names become the grid-table header row, each data-frame row becomes one body row, and column widths are calibrated from the widest formatted value in each column.
## S3 method for class 'data.frame'
as_gridtable(x, ...)
x |
A data frame. |
... |
Currently unused. |
Character scalar with class gridtable containing a canonical
Pandoc grid table.
as_gridtable, as_gridtable.character
Other gridtable:
as.data.frame.gridtable(),
as_calibrated(),
as_calibrated.data.frame(),
as_gridtable(),
as_gridtable.character(),
kbl(),
kbl.calibrated(),
kbl.default(),
kbl.gridtable(),
print.gridtable()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.